@@ -42,12 +42,14 @@ rfacebookstatWelcomeMessage <- function(){
          "---------------------\n",
          "Welcome to rfacebookstat version ", utils::packageDescription("rfacebookstat")$Version, "\n",
          "\n",
-         "Author:   Alexey Seleznev (Head of analytics dept at Netpeak).\n",
-		 "Telegram channel: https://t.me/R4marketing \n",
-         "Email:    selesnow@gmail.com\n",
-         "Blog:     https://alexeyseleznev.wordpress.com \n",
-         "Facebook: https://facebook.com/selesnown \n",
-         "Linkedin: https://www.linkedin.com/in/selesnow \n",
+         "Author:           Alexey Seleznev (Head of analytics dept at Netpeak).\n",
+         "Telegram channel: https://t.me/R4marketing \n",
+         "YouTube channel:  https://www.youtube.com/R4marketing/?sub_confirmation=1 \n",
+         "Email:            selesnow@gmail.com\n",
+         "Site:             https://selesnow.github.io \n",
+         "Blog:             https://alexeyseleznev.wordpress.com \n",
+         "Facebook:         https://facebook.com/selesnown \n",
+         "Linkedin:         https://www.linkedin.com/in/selesnow \n",
          "\n",
          "Type ?rfacebookstat for the main documentation.\n",
          "The github page is: https://github.com/selesnow/rfacebookstat/\n",
@@ -99,7 +101,7 @@ rfacebookstatWelcomeMessage <- function(){
   }
   
   op <- options()
-  op.rfacebookstat <- list(rfacebookstat.api_version  = "v6.0",
+  op.rfacebookstat <- list(rfacebookstat.api_version  = "v7.0",
                            rfacebookstat.access_token = fb_token,
                            rfacebookstat.accounts_id  = NULL,
                            rfacebookstat.business_id  = NULL,
